package jaxb.framework;

import java.util.Calendar;
import java.util.GregorianCalendar;
import javax.xml.bind.DatatypeConverter;
import java.math.BigInteger;
import java.text.SimpleDateFormat;
import java.text.ParseException;

/* ------------------------------------------------------------------
 * Name: JAXBDatatypeConverter
 * ------------------------------------------------------------------
 * Aufgaben:
 * ------------------------------------------------------------------
 * Bemerkungen:
 *
 *
 * ------------------------------------------------------------------
 * Einfhrungs- / nderungsgrund
 * - Core Dev.
 * ------------------------------------------------------------------
 * Erstellt am : 12.06.2003
 * ------------------------------------------------------------------
 * Teil eines Patterns:
 * ------------------------------------------------------------------
 * nderungen:
 * gendert am xx.xx.xxxx von xxxxxxxxxxxx
 * nderungsgrund
 */

/**
 * Methoden werden beim JAXB Binding verwendet, um die JAXB-Standard-Konvertierung von Java nach XML und XML nach Java zu modifizieren
 * @autor Christoph Brunner
 * @version 1.0
 */



public class JAXBDatatypeConverter {

/*  public static short parseIntegerToShort(String value) {
	BigInteger result = DatatypeConverter.parseInteger(value);
	return (short)(result.intValue());
  }

  public static String printShortToInteger(short value) {
        BigInteger result = BigInteger.valueOf(value);
        return DatatypeConverter.printInteger(result);
  }

  public static int parseIntegerToInt(String value) {
	BigInteger result = DatatypeConverter.parseInteger(value);
	return result.intValue();
  }

  public static String printIntToInteger(int value) {
       BigInteger result = BigInteger.valueOf(value);
       return DatatypeConverter.printInteger(result);
  }
*/

  public static Calendar parseStringToCalendar(String value)
  {
      return String2Calendar(value,"yyyy-MM-dd");
  }

  public static String printCalendarToString(Calendar value)
  {
    return Calendar2JJJJMMTTString(value,"-");
  }

  public static float parseFloatToFloat(String value)
  {
    return DatatypeConverter.parseFloat(value);
  }

  public static String printFloatToString(float value)
  {
    //Wenn der float Wert keinen relevanten Nachkomma Anteil hat (Der float Wert ist etwa "xxx.0")
    //dann wird der Nachkommastellenanteil abgeschnitten
    //Die berprfung wird folgendermaen vorgenommen
    //Es wird value modulo 1 gerechnet und wenn als Rest 0 herauskommt, dann knnen wir die Nachkommastellen entfernen
    String valueWithoutNachkommaString = new Integer(new Float(value).intValue()).toString();
    if (value % 1 == 0)
      return DatatypeConverter.printInteger(new BigInteger(valueWithoutNachkommaString));
    else
      return DatatypeConverter.printFloat(value);
  }

/**
 * Diese Methode konvertiert einen String in einen GregorianCalendar
 * @param datum Der String, welcher umgewandelt werden soll
 * @param format Formatangabe, mit Hilfe dessen die Umwandlung durchgefhrt wird (siehe API zu java.text.SimpleDateFormat)
 * @return Calendar Objekt, welches den Datums-String reprsentiert
 */
  private static Calendar String2Calendar(String datum,String format)
  {
    if (datum == null || datum.equals(""))
      return null;

    try
    {
      SimpleDateFormat df = new SimpleDateFormat(format);
      GregorianCalendar cal =  new GregorianCalendar();
      java.util.Date date = df.parse(datum);
      cal.setTime(date);
      return cal;
    }
    catch (ParseException ex)
    { /** tue nicht bei ParseException **/  }
    return null;
  }//String2Calendar()

/**
 * Diese Methode konvertiert einen Calendar in einen String im format: JJJJMMTT, dazwischen jeweils das trennzeichen
 * @param cal Der Calendar, welcher umgewandelt werden soll
 * @param trennzeichen Trennzeichen, welches zwischen Jahr, Monat und Tag gesetzt wird
 * @return Calendar Objekt, welches den Datums-String reprsentiert
 */
  private static String Calendar2JJJJMMTTString(Calendar cal, String trennzeichen)
  {
    if (cal == null)
      return null;
      
    int tag = cal.get(Calendar.DAY_OF_MONTH);
    int monat = cal.get(Calendar.MONTH)+1;
    int jahr = cal.get(Calendar.YEAR);

    String tagString = new Integer(tag).toString();
    String monatString = new Integer(monat).toString();
    String jahrString = new Integer(jahr).toString();
    
    if (tag < 10) tagString = "0"+tag;
    if (monat < 10) monatString = "0"+monat;
    
    return jahrString+trennzeichen+monatString+trennzeichen+tagString;
  }//Calendar2JJJMMTTString()  
}
